SchemaDefinition class
Constructors
-
SchemaDefinition({required Map<
String, SchemaProperty> properties})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
properties
→ Map<
String, SchemaProperty> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toSchemaProperty(
) → SchemaPropertyStructuredObjectWithDefinedProperties -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited