codex_cli_sdk library
A powerful Dart SDK for interacting with the OpenAI Codex CLI.
This SDK provides seamless integration with AI-powered coding assistance through the Codex CLI tool, enabling developers to build applications that leverage OpenAI's latest reasoning models.
Classes
- BytesContent
- This content type will create a temporary file from the provided bytes
-
CliChatInterface<
T extends CliChatOptions> - CliChatOptions
- Codex
- Main Codex SDK class for interacting with the OpenAI Codex CLI.
- CodexChat
- CodexChatOptions
- Options for configuring a Codex chat session.
-
CodingCliInterface<
C extends CliChatInterface< CliChatOptions> , O extends CliChatOptions> - FileContent
- McpAddOptions
- McpConfig
- McpInstallationInfo
- McpServer
- PromptContent
- SchemaDefinition
- SchemaProperty
- SchemaPropertyArray
- SchemaPropertyBoolean
- SchemaPropertyDouble
- SchemaPropertyEnum
- SchemaPropertyInteger
- SchemaPropertyObjectWithUndefinedProperties
- SchemaPropertyString
- SchemaPropertyStructuredObjectWithDefinedProperties
- TemporaryFiles
- TextContent
- Text content to be sent to Codex
Enums
Extensions
Properties
- filePreffix ↔ String
-
In some cli's, like claude code, files are prefixed with @ - so we can change it here
getter/setter pair
- schemaClassDeclaration → String
-
final
Typedefs
Exceptions / Errors
- CliException
- Base exception for all Codex SDK errors